/*

SPECIAL VERSION!

|    file name - dvtools.h
|===================================================================
|
|		copyright (c) 1986, V. I. Corporation
|
|       Scott Reed	Feb 17, 1986
|	R. Kohler	Feb 21, 1986	Add new stuff
|	Russell Turner  Feb 26, 1988	AXISDESC type
|       Scott Reed	Feb 13, 1989    removed DS type defines
|	K. Madison	Feb 01, 1990	Added Tproto types
|
|===================================================================
*/

#ifndef DVTOOLS_H
#define DVTOOLS_H

/* -------------------------------------------------------------------- */
#include "dstypes.h"

/* parameter definitions :						*/

#define NOCHANGE	-1  /* for attributes to remain unchanged*/

#define DSFAILMISSING	0   /* to fail when vars missing in master ds's*/
#define DSADDMISSING	1   /* to add vars when missing in master ds's*/
#define DS_EXACTMATCH	2   /* match ds's exactly when merging views */
#define DS_SUBSETMATCH	3   /* one ds must be a subset of another ds */
			    /* when merging views */
#define DS_NAMEMATCH	4   /* only ds names must match when merging */
			    /* views */

#define LOC_POLL	0   /* return valid location object in any event*/
#define WAIT_PICK	1   /* block until selection (key or button)*/
#define WAIT_CHANGE	2   /* block until cursor movement or key press*/
#define PICK_POLL	3   /* does not block, returns location object*/
			    /* only if there was a selection (key or*/
			    /* button) else retuns NULL*/


#define NAMED_SEARCH	0   /* search view for selection of named object*/
#define FULL_SEARCH	1   /* search entire view for selected object*/

#define DSASCII		2   /* ascii file or process datasource*/
#define DSBINARY	3   /* binary file or process datasource*/

/* -------------------------------------------------------------------- */
/* Dataviews Private Type definitions:					*/

#if 0
#define DRAWPORT	ADDRESS		/* dp	drawport */
#define VIEW		ADDRESS		/* vi	view */
#define DATASOURCELIST  ADDRESS		/* dl	data source list */
#define DATASOURCE	ADDRESS		/* ds	data source */
#define DSVAR		ADDRESS		/* dsv	data source variable */
#define OBJECT		LONG		/* ob	object */
#define INHANDLER	ADDRESS		/* ih	interaction handler */
#else
typedef ADDRESS	DRAWPORT;		/* dp	drawport */
typedef ADDRESS		VIEW;		/* vi	view */
typedef ADDRESS  DATASOURCELIST;		/* dl	data source list */
typedef ADDRESS	DATASOURCE;		/* ds	data source */
typedef ADDRESS		DSVAR;		/* dsv	data source variable */
#ifndef VOSTD_H
typedef LONG		OBJECT;		/* ob	object */
#endif
typedef ADDRESS	INHANDLER;		/* ih	interaction handler */
#endif

/* Obsolete names for some private types */
/* (see dvstd.h for more obsolete private data type names) */

#define LISTOFDSVARS	ADDRESS		/* same as DSVAR */
#define DRAWING_OBJECT  OBJECT		/* same as OBJECT */
#define SCREEN_OBJECT	OBJECT		/* same as OBJECT */
#define LOCATION_OBJECT OBJECT		/* same as OBJECT */
#define VARIABLE_DESCRIPTOR  ADDRESS	/* same as VARDESC */
#define VIEWPORT_OBJECT	OBJECT		/* same as OBJECT */

/* -------------------------------------------------------------------- */
/* globals set when opening, reading, closing datasources and */
/* when reading datasource variables */

GLOBALREF DATASOURCE M_dscurrent;/* current datasource being opened,
				    read or closed */
GLOBALREF DSVAR M_dsvcurrent;    /* current datasource variable
				    being read */

/* -------------------------------------------------------------------- */
/* Information needed for running prototypes with Tproto routines.*/
#define PROTO_ENV	ADDRESS	  /* prototype environment */
#define V_TPROTO_QUIT	-1        /* status from TprotoHandleInput */
typedef struct _PROTO_INFO *PROTO_INFO_PTR;

/*
  DRAWPORT_ATTRIBUTES typedef. Used by Tproto routines.
  This structure contains the attribures of a drawport: its virtual
  screen viewport (vvp), drawing's world viewport (wvp), and its
  aspect ratio flag (strech_flag).
*/
  typedef struct DRAWPORT_ATTRIBUTES
    {
    RECTANGLE *vvp;    /* where on the screen in virtual coords */
    RECTANGLE *wvp;    /* portion of the view in world coords */
    DV_BOOL stretch_flag; /* TRUE: TdpCreateStretch, FALSE: TdpCreate */
    } DRAWPORT_ATTRIBUTES;

typedef ADDRESS (*TDRFOREACHNAMEDOBJFUNPTR) V_P_((OBJECT obj,
					       char *name,
					       ADDRESS argblock));

typedef ADDRESS (*TDPTRAVERSEFUNPTR) V_P_((DRAWPORT drawport,
					   ADDRESS redraw_vp));
typedef void (*TDPREFRESHFUNPTR) V_P_((DRAWPORT drprt, RECTANGLE *rect,
				       ADDRESS args));
typedef ADDRESS (*TDLFOREACHDSFUNPTR) V_P_((DATASOURCE ds,
					    ADDRESS argblock));
typedef ADDRESS (*TDLFOREACHDSVFUNPTR) V_P_((DATASOURCE ds,
					     DSVAR dsv,
					     ADDRESS argblock));
typedef ADDRESS (*TDSFOREACHVARFUNPTR) V_P_((DSVAR dsv,
					     ADDRESS argblock));
typedef void (*TDSFREEFUNPTR) V_P_((ADDRESS data));
typedef ADDRESS (*TDSVFOREACHVDPFUNPTR) V_P_((VARDESC vdp, ADDRESS argblock));
typedef ADDRESS (*TDSVFOREACHREFFUNPTR) V_P_((VARDESC vdp, int type,
					      ADDRESS argblock));
typedef void (*TDSVFREEFUNPTR) V_P_((ADDRESS data));
typedef ADDRESS (*TVIFOREACHDSFUNPTR) V_P_((DATASOURCE ds, ADDRESS argblock));
typedef ADDRESS (*TVIFOREACHVARFUNPTR) V_P_((DATASOURCE ds, DSVAR dsv,
					     ADDRESS argblock));
typedef void (*VUDGTRVRSFUNPTR) V_P_((DATAGROUP dgp));
typedef void (*VUVDTRVRSFUNPTR) V_P_((VARDESC vdp));
#endif  /*DVTOOLS_H*/
